==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fAload.h <==
// class soot.coffi.Instruction_Aload

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 752ebc08c30d8e11 soot_coffi_Instruction__5fAload
// @dep_class 73e8eecee99f809f soot_coffi_Instruction__5fbytevar

// header file dependencies
// @dep_header soot_coffi_Instruction__5fbytevar

#include "soot/coffi/Instruction__5fbytevar.h"

#ifndef _JC_soot_coffi_Instruction__5fAload_H_
#define _JC_soot_coffi_Instruction__5fAload_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fAload$sub_refs	_jc_soot_coffi_Instruction__5fAload$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fAload$sub_nonrefs	_jc_soot_coffi_Instruction__5fAload$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fAload$refs	_jc_soot_coffi_Instruction__5fAload$refs;
typedef struct _jc_soot_coffi_Instruction__5fAload$nonrefs	_jc_soot_coffi_Instruction__5fAload$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fAload$object	_jc_soot_coffi_Instruction__5fAload$object;

typedef const struct _jc_soot_coffi_Instruction__5fAload$vmethods	_jc_soot_coffi_Instruction__5fAload$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fAload$vtable	_jc_soot_coffi_Instruction__5fAload$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fAload$vtype	_jc_soot_coffi_Instruction__5fAload$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fAload$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fAload$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fAload$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fAload$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbytevar$vmethods	soot_coffi_Instruction__5fbytevar;
	_jc_soot_coffi_Instruction__5fAload$vmethods	soot_coffi_Instruction__5fAload;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fAload$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fAload$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fAload$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fAload$refs {
    _jc_soot_coffi_Instruction__5fAload$sub_refs	soot_coffi_Instruction__5fAload;
    _jc_soot_coffi_Instruction__5fbytevar$sub_refs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fAload$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fAload$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbytevar$sub_nonrefs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction__5fAload$sub_nonrefs	soot_coffi_Instruction__5fAload;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fAload$object {
	_jc_soot_coffi_Instruction__5fAload$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fAload$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fAload$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fAload$vtype _jc_soot_coffi_Instruction__5fAload$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fAload, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fAload$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fAload_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fAload.h <==
// class soot.coffi.Instruction_Aload

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 752ebc08c30d8e11 soot_coffi_Instruction__5fAload
// @dep_class 73e8eecee99f809f soot_coffi_Instruction__5fbytevar

// header file dependencies
// @dep_header soot_coffi_Instruction__5fbytevar

#include "soot/coffi/Instruction__5fbytevar.h"

#ifndef _JC_soot_coffi_Instruction__5fAload_H_
#define _JC_soot_coffi_Instruction__5fAload_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fAload$sub_refs	_jc_soot_coffi_Instruction__5fAload$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fAload$sub_nonrefs	_jc_soot_coffi_Instruction__5fAload$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fAload$refs	_jc_soot_coffi_Instruction__5fAload$refs;
typedef struct _jc_soot_coffi_Instruction__5fAload$nonrefs	_jc_soot_coffi_Instruction__5fAload$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fAload$object	_jc_soot_coffi_Instruction__5fAload$object;

typedef const struct _jc_soot_coffi_Instruction__5fAload$vmethods	_jc_soot_coffi_Instruction__5fAload$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fAload$vtable	_jc_soot_coffi_Instruction__5fAload$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fAload$vtype	_jc_soot_coffi_Instruction__5fAload$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fAload$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fAload$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fAload$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fAload$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbytevar$vmethods	soot_coffi_Instruction__5fbytevar;
	_jc_soot_coffi_Instruction__5fAload$vmethods	soot_coffi_Instruction__5fAload;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fAload$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fAload$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fAload$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fAload$refs {
    _jc_soot_coffi_Instruction__5fAload$sub_refs	soot_coffi_Instruction__5fAload;
    _jc_soot_coffi_Instruction__5fbytevar$sub_refs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fAload$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fAload$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbytevar$sub_nonrefs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction__5fAload$sub_nonrefs	soot_coffi_Instruction__5fAload;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fAload$object {
	_jc_soot_coffi_Instruction__5fAload$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fAload$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fAload$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fAload$vtype _jc_soot_coffi_Instruction__5fAload$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fAload, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fAload$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fAload_H_ */
